==> gbook-0.11.tar.bz2: gbook/gbook.i18n-nl.php <==
<?

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "naam",
'f_origin'        => "herkomst",
'f_ip'            => "ip",
'f_browser'       => "browser",
'f_email'         => "emailadres",
'f_homepage'      => "webpagina",
'f_captcha'       => "captcha",
'f_entry'         => "bericht",
'f_ip'            => "ip",
'f_browser'       => "browser",

# buttons
'b_submit'        => "verzenden",
'b_reply'         => "antwoorden",
'b_change'        => "veranderen",
'b_delete'        => "verwijderen",
'b_reset'         => "legen",

# misc
'headline'        => "Gastenboek",
'hl_create'       => "Een nieuw bericht toevoegen:",
'hl_modify'       => "Een bericht veranderen:",
'new_entry'       => "Welkom op dit gastenboek. [{{fullurl:Special:Guestbook|action=add}} '''Hier'''] kunt u een nieuw bericht plaatsen.",
'entry_okay'      => "Ok, uw bericht is toegevoegd ;)",
'delete_okay'     => "Ok, het bericht is verwijderd.",
'change_okay'     => "Ok, het bericht is gewijzigd.",
'show_entries'    => "Laat berichten zien.",
'captcha_desc'    => "Neem de symbolen hieronder in het kleine plaatje over, a.u.b.",
'captcha_fail'    => "Sorry, uw captcha is niet correct!",
'err_name'        => "Sorry, U moet een naam opgeven!",
'err_entry'       => "Sorry, uw bericht lijkt leeg!",
'err_noentry'     => "Sorry, het bericht bestaat niet!",
'err_captcha'     => "Sorry, de captcha is leeg gelaten!"
);

?>

==> gbook-0.14.tar.bz2: gbook/gbook.i18n-nl.php <==
<?

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "naam",
'f_origin'        => "herkomst",
'f_ip'            => "ip",
'f_browser'       => "browser",
'f_email'         => "emailadres",
'f_homepage'      => "webpagina",
'f_captcha'       => "captcha",
'f_entry'         => "bericht",
'f_ip'            => "ip",
'f_browser'       => "browser",

# buttons
'b_submit'        => "verzenden",
'b_reply'         => "antwoorden",
'b_change'        => "veranderen",
'b_delete'        => "verwijderen",
'b_reset'         => "legen",

# misc
'headline'        => "Gastenboek",
'hl_create'       => "Een nieuw bericht toevoegen:",
'hl_modify'       => "Een bericht veranderen:",
'new_entry'       => "Welkom op dit gastenboek. [{{fullurl:$this->myAddPage|action=add}} '''Hier'''] kunt u een nieuw bericht plaatsen.",
'entry_okay'      => "Ok, uw bericht is toegevoegd ;)",
'delete_okay'     => "Ok, het bericht is verwijderd.",
'change_okay'     => "Ok, het bericht is gewijzigd.",
'show_entries'    => "Laat berichten zien.",
'captcha_desc'    => "Neem de symbolen hieronder in het kleine plaatje over, a.u.b.",
'captcha_fail'    => "Sorry, uw captcha is niet correct!",
'err_name'        => "Sorry, U moet een naam opgeven!",
'err_entry'       => "Sorry, uw bericht lijkt leeg!",
'err_noentry'     => "Sorry, het bericht bestaat niet!",
'err_captcha'     => "Sorry, de captcha is leeg gelaten!"
);

?>
